class GroupIcons:
    '''
    This class manages the access to group name and icons
    '''
    def __init__(self, icon_path=None):

        if icon_path:
            self.icon_path = icon_path if icon_path.endswith('/') else icon_path + "/"
            self.mini_icon_path = self.icon_path + "mini/"
        else:
            self.icon_path = '/usr/share/icons/'
            self.mini_icon_path = '/usr/share/icons/mini/'

        # TODO add a localized string for any group in "title"
        self._group_info = {
             'All' : { 
                'title' : _("All"), 
                'icon':  'system_section.svg'
                },
             'Accessibility' : {
                'title' : _("Accessibility"),
                'icon': 'accessibility_section.svg'
                },
             'Archiving' : {
                'title' : _("Archiving"),
                'icon': 'archiving_section.svg',
                'Backup' : {
                    'title' : _("Backup"),
                    'icon' : 'backup_section.svg'
                    },
                'Cd burning' : {
                    'title' : _("Cd burning"),
                    'icon' : 'cd_burning_section.svg'
                    },
                'Compression' : { 
                    'title' : _("Compression"),
                    'icon' : 'compression_section.svg'
                    },
                'Other' : {
                    'title' : _("Other"),
                    'icon' : 'other_archiving.png'
                    }
                },
                'Applications' : {
                'title' : _("Applications"),
                'icon': 'system_section.svg',
                'Internet' : {
                    'title' : _("Internet"),
                    'icon' : 'other_networking.svg'
                    }
                },
                'Books' : {
                'title' : _("Books"),
                'icon': 'education_section.svg',
                'Computer books' : {
                    'title' : _("Computer books"),
                    'icon' : 'documentation_section.svg'
                    },
                'Howtos' : {
                    'title' : _("Howtos"),
                    'icon' : 'office_section.svg'
                    },
                'Literature' : {
                    'title' : _("Literature"),
                    'icon' : 'news_section.svg'
                    },
                'Other' : {
                    'title' : _("Other"),
                    'icon' : 'editors_section.svg'
                    }
                },
                'Communications' : {
                        'title' : _("Communications"),
                        'icon'  : 'remote_access_section.svg',
                        'Bluetooth': {
                            'title' : _("Bluetooth"),
                            'icon'  : 'communications_bluetooth_section.svg',
                            },
                        'Dial-Up'  : {
                            'title' : _("Dial-Up"),
                            'icon'  : 'communications_dialup_section.svg',
                            },
                        'Fax'      : {
                            'title' : _("Fax"),
                            'icon'  : 'communications_fax_section.svg',
                            },
                        'Mobile'   : {
                            'title' : _("Mobile"),
                            'icon'  : 'communications_mobile_section',
                            },
                        'Radio'    : {
                            'title' : _("Radio"),
                            'icon'  : 'communications_radio_section.svg',
                            },
                        'Serial'   : {
                            'title' : _("Serial"),
                            'icon'  : 'communications_serial_section.svg',
                            },
                        'Telephony': {
                            'title' : _("Telephony"),
                            'icon'  : 'communications_phone_section',
                            },
                    },
                'Databases' : {
                    'title': _("Databases"),
                    'icon' :'databases_section.svg'
                 },
                'Development' : {
                    'title': _("Development"),
                    'icon' : 'development_section.svg',
                    'Basic' : {
                        'title' : _("Basic"),
                        },
                    'C' : {
                        'title' : _("C")
                        },
                    'C++' : {
                        'title' : _("C++"),
                        },
                    'C#' : {
                        'title' : _("C#"),
                        #'icon' : ''
                        },
                    'Databases' : {
                        'title' : _("Databases"),
                        'icon' : 'databases_section.svg'
                        },
                    'Debug' : {
                        'title' : _("Debug"),
                        #'icon' : ''
                        },
                    'Erlang' : {
                        'title' : _("Erlang"),
                        #'icon' : ''
                        },
                    'GNOME and GTK+' : {
                        'title' : _("GNOME and GTK+"),
                        'icon' : 'gnome_section.svg'
                        },
                    'Java' : {
                        'title' : _("Java"),
                        #'icon' : ''
                        },
                    'KDE and Qt' : {
                        'title' : _("KDE and Qt"),
                        'icon' : 'kde_section.svg'
                        },
                    'Kernel' : {
                        'title' : _("Kernel"),
                        #'icon' : ''
                        },
                    'OCaml' : {
                        'title' : _("OCaml"),
                        #'icon' : ''
                        },
                    'Other' : {
                        'title' : _("Other"),
                        #'icon' : ''
                        },
                    'Perl' : {
                        'title' : _("Perl"),
                        #'icon' : ''
                        },
                    'PHP' : {
                        'title' : _("PHP"),
                        #'icon' : ''
                        },
                    'Python' : {
                        'title' : _("Python"),
                        #'icon' : ''
                        },
                    'Tools' : {
                        'title' : _("Tools"),
                        'icon' : 'development_tools_section.svg',
                        },
                    'X11' : {
                        'title' : _("X11"),
                        #'icon' : ''
                        },
                },
                'Documentation' : {
                    'title' : _("Documentation"),
                    'icon' : 'documentation_section.svg'
                },
                'Editors' : {
                    'title' : _("Editors"),
                    'icon' : 'editors_section.svg'
                },
                'Unspecified' : {
                    'title' : _("Unspecified"),
                    'icon' : 'news_section.svg'
                },
                'Education' : {
                    'title' : _("Education"),
                    'icon' : 'education_section.svg'
                },
                'Empty' : {
                    'title' : _("Empty"),
                    #'icon' : TODO
                },
                'Emulators' : {
                    'title' : _("Emulators"),
                    #'icon' : TODO
                },
                'File tools' : {
                    'title' : _("File tools"),
                    'icon' : 'file_transfer_section.svg'
                },
                'Games' : {
                    'title' : _("Games"),
                    'icon' : 'amusement_section.svg',
                    'Adventure' : {
                        'title' : _("Adventure"),
                        'icon' : 'adventure_section.svg',
                    },
                    'Arcade' : {
                        'title' : _("Arcade"),
                        'icon' : 'arcade_section.svg',
                    },
                    'Boards' : {
                        'title' : _("Boards"),
                        'icon' : 'boards_section.svg',
                    },
                    'Cards' : {
                        'title' : _("Cards"),
                        'icon' : 'cards_section.svg',
                    },
                    'Other' : {
                        'title' : _("Other"),
                        'icon' : 'other_amusement.png',
                    },
                    'Puzzles' : {
                        'title' : _("Puzzles"),
                        'icon' : 'puzzle_section.svg',
                    },
                    'Shooter' : {
                        'title' : _("Shooter"),
                        'icon' : 'shooter_section.svg',
                    },
                    'Simulation' : {
                        'title' : _("Simulation"),
                        'icon' : 'simulation_section.svg',
                    },
                    'Sports' : {
                        'title' : _("Sports"),
                        'icon' : 'sport_section.svg',
                    },
                    'Strategy' : {
                        'title' : _("Strategy"),
                        'icon' : 'strategy_section.svg',
                    },
                },
                'Geography' : {
                    'title' : _("Geography"),
                    'icon' : 'geography_section.svg'
                },
                'Graphical desktop' : {
                    'title' : _("Graphical desktop"),
                    'icon' : 'graphical_desktop_section.svg',
                    'Enlightenment' : {
                        'title' : _("Enlightenment"),
                        'icon' : 'enlightment_section.svg',
                    },
                    'GNOME' : {
                        'title' : _("GNOME"),
                        'icon' : 'gnome_section.svg',
                    },
                    'Icewm' : {
                        'title' : _("Icewm"),
                        'icon' : 'icewm_section.svg',
                    },
                    'KDE' : {
                        'title' : _("KDE"),
                        'icon' : 'kde_section.svg',
                    },
                    'Other' : {
                        'title' : _("Other"),
                        'icon' : 'more_applications_other_section.svg',
                    },
                    'WindowMaker' : {
                        'title' : _("WindowMaker"),
                        'icon' : 'windowmaker_section.svg',
                    },
                    'Xfce' : {
                        'title' : _("Xfce"),
                        'icon' : 'xfce_section.svg',
                    },
                },
                'Graphics' : {
                    'title' : _("Graphics"),
                    'icon' : 'graphics_section.svg',
                    '3D' : {
                        'title' : _("3D"),
                        'icon' : 'graphics_3d_section.svg',
                    },
                    'Editors and Converters' : {
                        'title' : _("Editors and Converters"),
                        'icon' : 'graphics_editors_section.svg',
                    },
                    'Utilities' : {
                        'title' : _("Utilities"),
                        'icon' : 'graphics_utilities_section.svg',
                    },
                    'Photography' : {
                        'title' : _("Photography"),
                        'icon' : 'graphics_photography_section.svg',
                    },
                    'Scanning' : {
                        'title' : _("Scanning"),
                        'icon' : 'graphics_scanning_section.svg',
                    },
                    'Viewers' : {
                        'title' : _("Viewers"),
                        'icon' : 'graphics_viewers_section.svg',
                    },
                },
                'Monitoring' : {
                    'title' : _("Monitoring"),
                    'icon' : 'monitoring_section.svg'
                },
                'Networking' : {
                    'title' : _("Networking"),
                    'icon' : 'networking_section.svg',
                    'File transfer' : {
                        'title' : _("File transfer"),
                        'icon' : 'file_transfer_section.svg',
                    },
                    'IRC' : {
                        'title' : _("IRC"),
                        'icon' : 'irc_section.svg',
                    },
                    'Instant messaging' : {
                        'title' : _("Instant messaging"),
                        'icon' : 'instant_messaging_section.svg',
                    },
                    'Mail' : {
                        'title' : _("Mail"),
                        'icon' : 'mail_section.svg',
                    },
                    'News' : {
                        'title' : _("News"),
                        'icon' : 'news_section.svg',
                    },
                    'Other' : {
                        'title' : _("Other"),
                        'icon' : 'other_networking.png',
                    },
                    'Remote access' : {
                        'title' : _("Remote access"),
                        'icon' : 'remote_access_section.svg',
                    },
                    'WWW' : {
                        'title' : _("WWW"),
                        'icon' : 'networking_www_section.svg',
                    },
                },
                'Office' : {
                    'title' : _("Office"),
                    'icon' : 'office_section.svg',
                    'Dictionary' : {
                        'title' : _("Dictionary"),
                        'icon' : 'office_dictionary_section.svg',
                    },
                    'Finance' : {
                        'title' : _("Finance"),
                        'icon' : 'finances_section.svg',
                    },
                    'Management' : {
                        'title' : _("Management"),
                        'icon' : 'timemanagement_section.svg',
                    },
                    'Organizer' : {
                        'title' : _("Organizer"),
                        'icon' : 'timemanagement_section.svg',
                    },
                    'Utilities' : {
                        'title' : _("Utilities"),
                        'icon' : 'office_accessories_section.svg',
                    },
                    'Spreadsheet' : {
                        'title' : _("Spreadsheet"),
                        'icon' : 'spreadsheet_section.svg',
                    },
                    'Suite' : {
                        'title' : _("Suite"),
                        'icon' : 'office_suite.png',
                    },
                    'Word processor' : {
                        'title' : _("Word processor"),
                        'icon' : 'wordprocessor_section.svg',
                    },
                },
                'Publishing' : {
                    'title' : _("Publishing"),
                    'icon' : 'publishing_section.svg'
                },
                'Sciences' : {
                    'title' : _("Sciences"),
                    'icon' : 'sciences_section.svg',
                    'Astronomy' : {
                        'title' : _("Astronomy"),
                        'icon' : 'astronomy_section.svg',
                    },
                    'Biology' : {
                        'title' : _("Biology"),
                        'icon' : 'biology_section.svg',
                    },
                    'Chemistry' : {
                        'title' : _("Chemistry"),
                        'icon' : 'chemistry_section.svg',
                    },
                    'Computer science' : {
                        'title' : _("Computer science"),
                        'icon' : 'computer_science_section.svg',
                    },
                    'Geosciences' : {
                        'title' : _("Geosciences"),
                        'icon' : 'geosciences_section.svg',
                    },
                    'Mathematics' : {
                        'title' : _("Mathematics"),
                        'icon' : 'mathematics_section.svg',
                    },
                    'Other' : {
                        'title' : _("Other"),
                        'icon' : 'other_sciences.png',
                    },
                    'Physics' : {
                        'title' : _("Physics"),
                        'icon' : 'physics_section.svg',
                    },
                },
                'Security' : {
                    'title' : _("Security"),
                    #'icon' : TODO
                },
                'Shells' : {
                    'title' : _("Shells"),
                    #'icon' : TODO
                },
                'Sound' : {
                    'title' : _("Sound"),
                    'icon' : 'sound_section.svg',
                    'Editors and Converters' : {
                        'title' : _("Editors and Converters"),
                        'icon' : 'sound_editors_section.svg',
                    },
                    'Midi' : {
                        'title' : _("Midi"),
                        'icon' : 'sound_midi_section.svg',
                    },
                    'Mixers' : {
                        'title' : _("Mixers"),
                        'icon' : 'sound_mixers_section.svg',
                    },
                    'Players' : {
                        'title' : _("Players"),
                        'icon' : 'sound_players_section.svg',
                    },
                    'Utilities' : {
                        'title' : _("Utilities"),
                        'icon' : 'sound_utilities_section.svg',
                    },
                },
                'System' : {
                    'title' : _("System"),
                    'icon' : 'system_section.svg',
                    'Base' : {
                        'title' : _("Base"),
                        'icon' : 'system_section.svg',
                    },
                    'Boot and Init' : {
                        'title' : _("Boot and Init"),
                        'icon' : 'boot_init_section.svg',
                    },
                    'Cluster' : {
                        'title' : _("Cluster"),
                        'icon' : 'parallel_computing_section.svg',
                    },
                    'Configuration' : {
                        'title' : _("Configuration"),
                        'icon' : 'configuration_section.svg',
                    },
                    'Fonts' : {
                        'title' : _("Fonts"),
                        'icon' : 'chinese_section.svg',
                        'True type' : {
                            'title' : _("True type"),
                            #'icon' : '',
                        },
                        'Type1' : {
                            'title' : _("Type1"),
                            #'icon' : '',
                        },
                        'X11 bitmap' : {
                            'title' : _("X11 bitmap"),
                            #'icon' : '',
                        },
                    },
                    'Internationalization' : {
                        'title' : _("Internationalization"),
                        'icon' : 'chinese_section.svg',
                    },
                    'Kernel and hardware' : {
                        'title' : _("Kernel and hardware"),
                        'icon' : 'hardware_configuration_section.svg',
                    },
                    'Libraries' : {
                        'title' : _("Libraries"),
                        'icon' : 'system_section.svg',
                    },
                    'Networking' : {
                        'title' : _("Networking"),
                        'icon' : 'networking_configuration_section.svg',
                    },
                    'Packaging' : {
                        'title' : _("Packaging"),
                        'icon' : 'packaging_section.svg',
                    },
                    'Printing' : {
                        'title' : _("Printing"),
                        'icon' : 'printing_section.svg',
                    },
                    'Servers' : {
                        'title' : _("Servers"),
                        'icon' : 'servers_section.svg',
                    },
                    'X11' : {
                        'title' : _("X11"),
                        'icon' : 'x11_section.svg',
                    },
                },
                'Terminals' : {
                    'title' : _("Terminals"),
                    #'icon' : TODO
                },
                'Text tools' : {
                    'title' : _("Text tools"),
                    'icon' : 'editors_section.svg'
                },
                'Toys' : {
                    'title' : _("Toys"),
                    'icon' : 'toys_section.svg'
                },
                'Video' : {
                    'title' : _("Video"),
                    'icon' : 'video_section.svg',
                    'Editors and Converters' : {
                        'title' : _("Editors and Converters"),
                        'icon' : 'video_editors_section.svg',
                    },
                    'Players' : {
                        'title' : _("Players"),
                        'icon' : 'video_players_section.svg',
                    },
                    'Television' : {
                        'title' : _("Television"),
                        'icon' : 'video_television_section.svg',
                    },
                    'Utilities' : {
                        'title' : _("Utilities"),
                        'icon' : 'video_utilities_section.svg',
                    },
                },
                'System Environment' : {
                'title' : _("System Environment"),
                'icon': 'configuration_section.svg',
                'Libraries' : {
                    'title' : _("Libraries"),
                    'icon' : 'news_section.svg'
                    }
                },
                ## for Mageia Choice:
                'Workstation' : {
                    'title' : _("Workstation"),
                    'icon' : 'system_section.svg',
                    'Configuration' : {
                        'title' : _("Configuration"),
                        'icon' : 'configuration_section.svg',
                    },
                    'Console Tools' : {
                        'title' : _("Console Tools"),
                        'icon' : 'interpreters_section.svg',
                    },
                    'Documentation' : {
                        'title' : _("Documentation"),
                        'icon' : 'documentation_section.svg',
                    },
                    'Game station' : {
                        'title' : _("Game station"),
                        'icon' : 'amusement_section.svg',
                    },
                    'Internet station' : {
                        'title' : _("Internet station"),
                        'icon' : 'networking_section.svg',
                    },
                    'Multimedia station' : {
                        'title' : _("Multimedia station"),
                        'icon' : 'multimedia_section.svg',
                    },
                    'Network Computer (client)' : {
                        'title' : _("Network Computer (client)"),
                        'icon' : 'other_networking.png',
                    },
                    'Office Workstation' : {
                        'title' : _("Office Workstation"),
                        'icon' : 'office_section.svg',
                    },
                    'Scientific Workstation' : {
                        'title' : _("Scientific Workstation"),
                        'icon' : 'sciences_section.svg',
                    },
                },
                'Graphical Environment' : {
                    'title' : _("Graphical Environment"),
                    'icon' : 'graphical_desktop_section.svg',
                    'GNOME Workstation' : {
                        'title' : _("GNOME Workstation"),
                        'icon' : 'gnome_section.svg',
                    },
                    'IceWm Desktop' : {
                        'title' : _("IceWm Desktop"),
                        'icon' : 'icewm_section.svg',
                    },
                    'KDE Workstation' : {
                        'title' : _("KDE Workstation"),
                        'icon' : 'kde_section.svg',
                    },
                    'Other Graphical Desktops' : {
                        'title' : _("Other Graphical Desktops"),
                        'icon' : 'more_applications_other_section.svg',
                    },
                },
                'Development' : {
                    'title' : _("Development"),
                    'icon' : 'development_section.svg',
                    'Development' : {
                        'title' : _("Development"),
                        'icon' : 'development_section.svg',
                    },
                    'Documentation' : {
                        'title' : _("Documentation"),
                        'icon' : 'documentation_section.svg',
                    },
                },
                'Search' : {
                    'title' : _("Search result"),
                    #'icon' : TODO
                },
                'Server' : {
                    'title' : _("Server"),
                    'icon' : 'servers_section.svg',
                    'DNS/NIS' : {
                        'title' : _("DNS/NIS"),
                        'icon' : 'networking_section.svg',
                    },
                    'Database' : {
                        'title' : _("Database"),
                        'icon' : 'databases_section.svg',
                    },
                    'Firewall/Router' : {
                        'title' : _("Firewall/Router"),
                        'icon' : 'networking_section.svg',
                    },
                    'Mail' : {
                        'title' : _("Mail"),
                        'icon' : 'mail_section.svg',
                    },
                    'Mail/Groupware/News' : {
                        'title' : _("Mail/Groupware/News"),
                        'icon' : 'mail_section.svg',
                    },
                     'Network Computer server' : {
                        'title' : _("Network Computer server"),
                        'icon' : 'networking_section.svg',
                    },
                     'Web/FTP' : {
                        'title' : _("Web/FTP"),
                        'icon' : 'networking_www_section.svg',
                    },
                },
            }


    @property
    def groups(self):
        '''
        return all the group info
        '''
        return self._group_info
    
    def _group(self, k, group_dic) :
        if k in group_dic:
            return group_dic[k]
        return None
    
    def icon(self, group, separator='/') :
        '''
        from the given group as a pathname return the related icon
        if icon_path is passed to the constructor, icon_path/ and icon_path/mini
        are used to return icon_name
        '''
       
        groups = group.split(separator)
        icon_path =  self.mini_icon_path if len(groups) > 1 else self.icon_path
        g = self._group_info
        for k in groups:
            if k in g.keys():
                g = g[k]
            else:
                g = None
                break
        
        if g and 'icon' in g:
            icon_path += g['icon']
        else:
            icon_path += "applications_section.svg"
            
        return icon_path

